@@ -9,7 +9,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2010-2018 The MathJax Consortium
+ *  Copyright (c) 2010-2020 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,9 +25,13 @@
  */
 
 MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
-  var VERSION = "2.7.4";
+  var VERSION = "2.7.9";
   var MML = MathJax.ElementJax.mml,
       HTMLCSS = MathJax.OutputJax["HTML-CSS"];
+  //
+  //  Fake node used for testing end-of-line potential breakpoint
+  //
+  var MO = MML.mo().With({HTMLspanElement: function () {return {bbox: {w:0}, style: {}}}});
       
   //
   //  Penalties for the various line breaks
@@ -109,7 +113,7 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
           },
           broken = false;
           
-      while (this.HTMLbetterBreak(end,state) && 
+      while (this.HTMLbetterBreak(end,state,true) && 
              (end.scanW >= HTMLCSS.linebreakWidth || end.penalty === PENALTY.newline)) {
         this.HTMLaddLine(stack,start,end.index,state,end.values,broken);
         start = end.index.slice(0); broken = true;
@@ -125,10 +129,7 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
       //  Make top-level spans 100% wide.
       //  Finish up the space and add the color again
       //
-      if (isTop) {
-        stack.style.width = "100%";
-        if (parent.type === "math") {span.bbox.width = "100%"}
-      }
+      if (parent.type === "math") {stack.style.width = span.bbox.width = "100%"}
       this.HTMLhandleSpace(span);
       this.HTMLhandleColor(span);
       span.bbox.isMultiline = true;
@@ -140,7 +141,7 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
     //
     //  Locate the next linebreak that is better than the current one
     //
-    HTMLbetterBreak: function (info,state) {
+    HTMLbetterBreak: function (info,state,toplevel) {
       if (this.isToken) {return false}  // FIXME: handle breaking of token elements
       if (this.isEmbellished()) {
         info.embellished = this;
@@ -172,6 +173,13 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
         }
         info.index = []; i++; broken = false;
       }
+      //
+      //  Check if end-of-line is a better breakpoint
+      //
+      if (toplevel && better) {
+        MO.parent = this.parent; MO.inherit = this.inherit;
+        if (MO.HTMLbetterBreak(info,state)) {better = false; index = info.index}
+      }
       if (info.nest) {info.nest--}
       info.index = index;
       if (better) {info.W = W; info.w = w}
@@ -524,7 +532,11 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
           var box = s.HTMLspanElement().parentNode;
           if (s.href) box = box.parentNode;
           var stack = box.parentNode;
-          if (this.data[this.base]) {stack.removeChild(stack.firstChild)}
+          if (this.data[this.base]) {
+            var ic = this.data[this.base].HTMLspanElement().bbox.ic;
+            if (ic) stack.style.marginLeft = HTMLCSS.Em(-ic);
+            stack.removeChild(stack.firstChild);
+          }
 	  for (box = stack.firstChild; box; box = box.nextSibling)
 	    {box.style.left = HTMLCSS.Em(HTMLCSS.unEm(box.style.left)-this.HTMLbaseW)}
           stack.bbox.w -= this.HTMLbaseW; stack.style.width = HTMLCSS.Em(stack.bbox.w);
@@ -686,10 +698,10 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
       //  Get the penalty for this type of break and
       //    use it to modify the default penalty
       //
-      var linebreak = PENALTY[values.linebreak||MML.LINEBREAK.AUTO];
+      var linebreak = PENALTY[values.linebreak||MML.LINEBREAK.AUTO]||0;
       if (!MathJax.Object.isArray(linebreak)) {
-        //  for breaks past the width, don't modify penalty
-        if (offset >= 0) {penalty = linebreak * info.nest}
+        //  for breaks past the width, keep original penalty for newline
+        if (linebreak || offset >= 0) {penalty = linebreak * info.nest}
       } else {penalty = Math.max(1,penalty + linebreak[0] * info.nest)}
       //
       //  If the penalty is no better than the current one, return false
@@ -733,13 +745,13 @@ MathJax.Hub.Register.StartupHook("HTML-CSS Jax Ready",function () {
       //  Get the penalty for this type of break and
       //    use it to modify the default penalty
       //
-      var linebreak = PENALTY[linebreakValue];
+      var linebreak = PENALTY[linebreakValue]||0;
       if (linebreakValue === MML.LINEBREAK.AUTO && w >= PENALTY.spacelimit &&
           !this.mathbackground && !this.background)
         {linebreak = [(w+PENALTY.spaceoffset)*PENALTY.spacefactor]}
       if (!MathJax.Object.isArray(linebreak)) {
-        //  for breaks past the width, don't modify penalty
-        if (offset >= 0) {penalty = linebreak * info.nest}
+        //  for breaks past the width, keep original penalty for newline
+        if (linebreak || offset >= 0) {penalty = linebreak * info.nest}
       } else {penalty = Math.max(1,penalty + linebreak[0] * info.nest)}
       //
       //  If the penalty is no better than the current one, return false
