@@ -2,7 +2,7 @@
  *
  *  MathJax/jax/output/HTML-CSS/fonts/STIX-Web/Normal/Italic/Main.js
  *  
- *  Copyright (c) 2013-2018 The MathJax Consortium
+ *  Copyright (c) 2013-2020 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,6 +22,105 @@ MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['STIXMathJax_Normal-italic'] = {
   family: 'STIXMathJax_Normal',
   style: 'italic',
   testString: '\u00A0\u210E\uD835\uDC34\uD835\uDC35\uD835\uDC36\uD835\uDC37\uD835\uDC38\uD835\uDC39\uD835\uDC3A\uD835\uDC3B\uD835\uDC3C\uD835\uDC3D\uD835\uDC3E\uD835\uDC3F\uD835\uDC40',
+  skew: {
+    0x1D434: .16,
+    0x1D435: .14,
+    0x1D436: .12,
+    0x1D437: .1,
+    0x1D438: .1,
+    0x1D439: .1,
+    0x1D43A: .12,
+    0x1D43B: .1,
+    0x1D43C: .1,
+    0x1D43D: .1,
+    0x1D43E: .1,
+    0x1D43F: .05,
+    0x1D440: .08,
+    0x1D441: .08,
+    0x1D442: .12,
+    0x1D443: .05,
+    0x1D444: .12,
+    0x1D445: .1,
+    0x1D446: .12,
+    0x1D44B: .12,
+    0x1D44C: -.05,
+    0x1D44D: .1,
+    0x1D44E: .09,
+    0x1D44F: .03,
+    0x1D450: .09,
+    0x1D451: .2,
+    0x1D452: .09,
+    0x1D453: .19,
+    0x1D454: .08,
+    0x1D456: .08,
+    0x1D457: .16,
+    0x1D459: .09,
+    0x1D45A: .09,
+    0x1D45B: .05,
+    0x1D45C: .09,
+    0x1D45D: .09,
+    0x1D45E: .1,
+    0x1D45F: .07,
+    0x1D460: .07,
+    0x1D461: .07,
+    0x1D462: .05,
+    0x1D463: .08,
+    0x1D464: .1,
+    0x1D465: .05,
+    0x1D466: .1,
+    0x1D467: .07,
+    0x1D6A4: .05,
+    0x1D6A5: .07,
+    0x1D6E2: .16,
+    0x1D6E3: .14,
+    0x1D6E4: .09,
+    0x1D6E5: .16,
+    0x1D6E6: .14,
+    0x1D6E7: .14,
+    0x1D6E8: .1,
+    0x1D6E9: .12,
+    0x1D6EA: .1,
+    0x1D6EB: .12,
+    0x1D6EC: .16,
+    0x1D6ED: .12,
+    0x1D6EE: .1,
+    0x1D6EF: .14,
+    0x1D6F0: .14,
+    0x1D6F1: .12,
+    0x1D6F2: .08,
+    0x1D6F3: .14,
+    0x1D6F4: .14,
+    0x1D6F7: .12,
+    0x1D6F8: .14,
+    0x1D6FA: .16,
+    0x1D6FB: .05,
+    0x1D6FC: .05,
+    0x1D6FD: .1,
+    0x1D6FE: .05,
+    0x1D6FF: .12,
+    0x1D700: .07,
+    0x1D701: .07,
+    0x1D702: .05,
+    0x1D703: .09,
+    0x1D704: .05,
+    0x1D706: .07,
+    0x1D707: .1,
+    0x1D708: .07,
+    0x1D709: .12,
+    0x1D70A: .08,
+    0x1D70B: .08,
+    0x1D70C: .1,
+    0x1D70D: .1,
+    0x1D70E: .05,
+    0x1D710: .05,
+    0x1D711: .05,
+    0x1D712: .09,
+    0x1D714: .05,
+    0x1D716: .1,
+    0x1D717: .1,
+    0x1D71A: .1,
+    0x1D71B: .07,
+  },
   0x20: [0,0,250,0,0],
   0xA0: [0,0,250,0,0],
   0x210E: [668,11,513,45,483],
