@@ -2,7 +2,7 @@
  *
  *  MathJax/jax/output/HTML-CSS/fonts/STIX/General/Italic/GreekItalic.js
  *
- *  Copyright (c) 2009-2018 The MathJax Consortium
+ *  Copyright (c) 2009-2020 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -21,6 +21,57 @@
 MathJax.Hub.Insert(
   MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['STIXGeneral-italic'],
   {
+    skew: {
+      0x1D6E2: .16,
+      0x1D6E3: .14,
+      0x1D6E4: .09,
+      0x1D6E5: .16,
+      0x1D6E6: .14,
+      0x1D6E7: .14,
+      0x1D6E8: .1,
+      0x1D6E9: .12,
+      0x1D6EA: .1,
+      0x1D6EB: .12,
+      0x1D6EC: .16,
+      0x1D6ED: .12,
+      0x1D6EE: .1,
+      0x1D6EF: .14,
+      0x1D6F0: .14,
+      0x1D6F1: .12,
+      0x1D6F2: .08,
+      0x1D6F3: .14,
+      0x1D6F4: .14,
+      0x1D6F7: .12,
+      0x1D6F8: .14,
+      0x1D6FA: .16,
+      0x1D6FB: .05,
+      0x1D6FC: .05,
+      0x1D6FD: .1,
+      0x1D6FE: .05,
+      0x1D6FF: .12,
+      0x1D700: .07,
+      0x1D701: .07,
+      0x1D702: .05,
+      0x1D703: .09,
+      0x1D704: .05,
+      0x1D706: .07,
+      0x1D707: .1,
+      0x1D708: .07,
+      0x1D709: .12,
+      0x1D70A: .08,
+      0x1D70B: .08,
+      0x1D70C: .1,
+      0x1D70D: .1,
+      0x1D70E: .05,
+      0x1D710: .05,
+      0x1D711: .05,
+      0x1D712: .09,
+      0x1D714: .05,
+      0x1D716: .1,
+      0x1D717: .1,
+      0x1D71A: .1,
+      0x1D71B: .07,
+    },
     0x1D6E2: [667,0,717,35,685],       // MATHEMATICAL ITALIC CAPITAL ALPHA
     0x1D6E3: [653,0,696,38,686],       // MATHEMATICAL ITALIC CAPITAL BETA
     0x1D6E4: [653,0,616,38,721],       // MATHEMATICAL ITALIC CAPITAL GAMMA
