@@ -2,7 +2,7 @@
  *
  *  MathJax/jax/output/SVG/fonts/STIX-Web/Normal/BoldItalic/Main.js
  *  
- *  Copyright (c) 2013-2018 The MathJax Consortium
+ *  Copyright (c) 2013-2020 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -23,6 +23,108 @@ MathJax.OutputJax['SVG'].FONTDATA.FONTS['STIXMathJax_Normal-bold-italic'] = {
   weight: 'bold',
   style: 'italic',
   id: 'STIXWEBNORMALBI',
+  skew: {
+    0x1D468: .16,
+    0x1D469: .14,
+    0x1D46A: .12,
+    0x1D46B: .1,
+    0x1D46C: .1,
+    0x1D46D: .1,
+    0x1D46E: .12,
+    0x1D46F: .1,
+    0x1D470: .1,
+    0x1D471: .1,
+    0x1D472: .1,
+    0x1D473: .05,
+    0x1D474: .08,
+    0x1D475: .08,
+    0x1D476: .12,
+    0x1D477: .05,
+    0x1D478: .12,
+    0x1D479: .1,
+    0x1D47A: .12,
+    0x1D47D: -.05,
+    0x1D47E: -.09,
+    0x1D47F: .12,
+    0x1D480: -.05,
+    0x1D481: .1,
+    0x1D482: .09,
+    0x1D483: .03,
+    0x1D484: .09,
+    0x1D485: .22,
+    0x1D486: .09,
+    0x1D487: .19,
+    0x1D488: .08,
+    0x1D48A: .1,
+    0x1D48B: .16,
+    0x1D48D: .09,
+    0x1D48E: .09,
+    0x1D48F: .05,
+    0x1D490: .09,
+    0x1D491: .09,
+    0x1D492: .1,
+    0x1D493: .07,
+    0x1D494: .07,
+    0x1D495: .09,
+    0x1D496: .05,
+    0x1D497: .08,
+    0x1D498: .1,
+    0x1D499: .05,
+    0x1D49A: .1,
+    0x1D49B: .07,
+    0x1D71C: .16,
+    0x1D71D: .14,
+    0x1D71E: .09,
+    0x1D71F: .16,
+    0x1D720: .14,
+    0x1D721: .14,
+    0x1D722: .1,
+    0x1D723: .12,
+    0x1D724: .1,
+    0x1D725: .12,
+    0x1D726: .16,
+    0x1D727: .11,
+    0x1D728: .1,
+    0x1D729: .14,
+    0x1D72A: .14,
+    0x1D72B: .12,
+    0x1D72C: .08,
+    0x1D72D: .14,
+    0x1D72E: .14,
+    0x1D731: .12,
+    0x1D732: .14,
+    0x1D734: .16,
+    0x1D735: .05,
+    0x1D736: .05,
+    0x1D737: .1,
+    0x1D738: .05,
+    0x1D739: .12,
+    0x1D73A: .07,
+    0x1D73B: .09,
+    0x1D73C: .07,
+    0x1D73D: .1,
+    0x1D73E: .05,
+    0x1D740: .07,
+    0x1D741: .1,
+    0x1D742: .07,
+    0x1D743: .12,
+    0x1D744: .08,
+    0x1D745: .08,
+    0x1D746: .1,
+    0x1D747: .1,
+    0x1D748: .05,
+    0X1D749: .05,
+    0x1D74A: .05,
+    0x1D74B: .05,
+    0x1D74C: .09,
+    0x1D74E: .05,
+    0x1D750: .1,
+    0x1D751: .1,
+    0X1D752: .05,
+    0X1D753: .12,
+    0x1D754: .1,
+    0x1D755: .09,
+  },
   0x20: [0,0,250,0,0,''],
   0xA0: [0,0,250,0,0,''],
   0x1D468: [685,0,759,39,724,'724 23l-2 -23h-319l4 23h31c33 0 51 17 51 45c0 10 -1 28 -2 34l-15 108h-159l-80 -139c-2 -4 -6 -13 -6 -22c0 -19 9 -26 22 -26h56l-6 -23h-260l4 23c45 5 74 17 108 75l346 587h49l94 -624c4 -24 20 -38 47 -38h37zM466 256l-23 178l-103 -178h126'],
